@@ -79,7 +79,7 @@ sub _check_permissions ( $self, $method_id ) {
         }
     }
     else {
-        return res 200 if $method_permissions eq $PERMISSION_ANY_AUTHENTICATED_USER && $self->{is_authenticated};
+        return res 200 if $method_permissions eq $PERMISSIONS_ANY_AUTHENTICATED_USER && $self->{is_authenticated};
     }
 
     return res [ 403, qq[Insufficient permissions for method "$method_id"] ];
